# -*- coding: utf-8 -*-
from __future__ import unicode_literals
"""Physplotlib.

This program treats raw data of resistive switching measurements in
order to obtain several key statistical values. For more information consult
the readeMe.txt file

"""


from resswitch import resSwitch


__all__ = ["resSwitch"]
